@@ -181,17 +181,15 @@ our sub to-json($obj is copy, Bool :$pretty = True, Int :$level = 0, Int :$spaci
     return $out;
 }
 
-my sub nom-ws(str $text, int $pos is rw) {
-    my int $wsord;
-    nqp::handle(
-        nqp::while(1,
-            nqp::stmts(
-                ($wsord = nqp::ordat($text, $pos)),
-                (last unless $wsord == 32 || $wsord == 10 || $wsord == 13 || $wsord == 9),
-                ($pos = $pos + 1)
-            )),
-            'CATCH',
-            (die "reached end of string when looking for something"));
+my $ws := nqp::list_i;
+nqp::bindpos_i($ws,$_ + 1,1) for 9,10,13,32;  # allow for -1 as value
+my sub nom-ws(str $text, int $pos is rw --> Nil) {
+    nqp::while(
+      nqp::atpos_i($ws,nqp::ordat($text,$pos) + 1),
+      $pos = $pos + 1
+    );
+    die "reached end of string when looking for something"
+      if $pos == nqp::chars($text);
 }
 
 my sub tear-off-combiners(str $text, int $pos) {
@@ -298,8 +296,8 @@ my sub parse-string(str $text, int $pos is rw) {
         $raw = $startcombiner ~ $raw
     }
     if not $has_treacherous and not $has_hexcodes and $escape_counts {
-        my @a;
-        my @b;
+        my str @a;
+        my str @b;
         if nqp::existskey($escape_counts, "n") and nqp::existskey($escape_counts, "r") {
             @a.push("\\r\\n"); @b.push("\r\n");
         }
@@ -316,7 +314,7 @@ my sub parse-string(str $text, int $pos is rw) {
             @a.push('\\"'); @b.push('"');
         }
         if nqp::existskey($escape_counts, "/") {
-            @a.push("\\/"), @b.push("/");
+            @a.push("\\/"); @b.push("/");
         }
         if nqp::existskey($escape_counts, "\\") {
             @a.push("\\\\"); @b.push("\\");
@@ -486,7 +484,7 @@ my sub parse-thing(str $text, int $pos is rw) {
 
     $pos = $pos + 1;
 
-    if ord($initial) == 34 { # "
+    if nqp::ord($initial) == 34 { # "
         parse-string($text, $pos);
     } elsif $initial eq '[' {
         parse-array($text, $pos);
